@@ -170,7 +170,7 @@ impl HttpCaller for Client {
 }
 
 fn make_user_agent(request: &RequestParts) -> Result<HeaderValue, ResponseError> {
-    HeaderValue::from_str(&format!("{}/qiniu-http-{}", request.user_agent(), isahc::version(),)).map_err(|err| {
+    HeaderValue::from_str(&format!("{}/qiniu-{}", request.user_agent(), isahc::version(),)).map_err(|err| {
         ResponseError::builder(ResponseErrorKind::InvalidHeader, err)
             .uri(request.url())
             .build()
@@ -580,7 +580,7 @@ fn from_isahc_error(err: IsahcError, request: &RequestParts) -> ResponseError {
         IsahcErrorKind::InvalidCredentials => ResponseError::builder(ResponseErrorKind::InvalidHeader, err),
         IsahcErrorKind::InvalidRequest => ResponseError::builder(ResponseErrorKind::InvalidRequestResponse, err),
         IsahcErrorKind::Io => ResponseError::builder(ResponseErrorKind::SendError, err),
-        IsahcErrorKind::NameResolution => ResponseError::builder(ResponseErrorKind::LocalIoError, err),
+        IsahcErrorKind::NameResolution => ResponseError::builder(ResponseErrorKind::UnknownHostError, err),
         IsahcErrorKind::ProtocolViolation => ResponseError::builder(ResponseErrorKind::InvalidRequestResponse, err),
         IsahcErrorKind::Timeout => ResponseError::builder(ResponseErrorKind::TimeoutError, err),
         IsahcErrorKind::TlsEngine => ResponseError::builder(ResponseErrorKind::SslError, err),
